==> 0.1.0.tar.gz: lib/src/matchers/string_matchers.dart <==
// Copyright (c) 2012, Ladislav Thon. All rights reserved. Use of this source
// code is governed by a BSD-style license that can be found in the LICENSE file.

class _Empty implements Matcher<String> {
  bool matches(String value) => value.isEmpty();
  String get description => "be empty";
}

class _EqualsIgnoreCase extends SimpleMatcher<String> {
  _EqualsIgnoreCase(String value) : super(value);

  bool matches(String value) => value.toLowerCase() == savedValue.toLowerCase();
  String get description => "be equal to '$savedValue' when ignoring case";
}

class _BeginsWith extends SimpleMatcher<String> {
  _BeginsWith(String value) : super(value);

  bool matches(String value) => value.startsWith(savedValue);
  String get description => "begin with '$savedValue'";
}

class _EndsWith extends SimpleMatcher<String> {
  _EndsWith(String value) : super(value);

  bool matches(String value) => value.endsWith(savedValue);
  String get description => "end with '$savedValue'";
}

class _Contains extends SimpleMatcher<String> {
  _Contains(String value) : super(value);

  bool matches(String value) => value.contains(savedValue, 0);
  String get description => "contain '$savedValue'";
}

class _MatchesRegExp implements Matcher<String> {
  RegExp _regexp;

  _MatchesRegExp(this._regexp);

  _MatchesRegExp.fromString(String pattern) : _regexp = new RegExp(pattern);

  bool matches(String value) => _regexp.hasMatch(value);
  String get description => "match '${_regexp.pattern}'";
}

class _StringForm implements Matcher {
  Matcher<String> _matcher;

  _StringForm(this._matcher);

  bool matches(value) => _matcher.matches("$value");
  String get description => "string ${_matcher.description}";
}

/// Every string that is empty (i.e., `it.isEmtpy()`) matches.
Matcher<String> empty() => new _Empty();

/// Every string that is equal to given [value] ignoring case
/// (i.e., `it.toLowerCase() == value.toLowerCase()`) matches.
Matcher<String> equalsIgnoreCase(String value) => new _EqualsIgnoreCase(value);

/// Every string that begins with given [value] (i.e., `it.startsWith(value)`)
/// matches.
Matcher<String> beginsWith(String value) => new _BeginsWith(value);

/// Every string that ends with given [value] (i.e., `it.endsWith(value)`)
/// matches.
Matcher<String> endsWith(String value) => new _EndsWith(value);

/// Every string that contains given [value] (i.e., `it.contains(value)`)
/// matches.
Matcher<String> contains(String value) => new _Contains(value);

/// Every string that matches given regular expression [pattern]
/// (i.e., `regexp.hasMatch(it)`) matches. Note that the [pattern]
/// can either be a [RegExp], in which case it is used directly,
/// or a [String], in which case it is passed to `new RegExp()`.
Matcher<String> matches(pattern) {
  if (pattern is String) {
    return new _MatchesRegExp.fromString(pattern);
  } else if (pattern is RegExp) {
    return new _MatchesRegExp(pattern);
  } else {
    throw new IllegalArgumentException("'$pattern' must be String or RegExp");
  }
}

/// Matches only if the string form (as per `toString()`) matches given [matcher].
Matcher stringForm(Matcher<String> matcher) => new _StringForm(matcher);

==> 0.2.0.tar.gz: lib/src/matchers/string_matchers.dart <==
// Copyright (c) 2012, Ladislav Thon. All rights reserved. Use of this source
// code is governed by a BSD-style license that can be found in the LICENSE file.

part of matchers;

class _Empty implements Matcher<String> {
  bool matches(String value) => value.isEmpty;
  String get description => "be empty";
}

class _EqualsIgnoreCase extends SimpleMatcher<String> {
  _EqualsIgnoreCase(String value) : super(value);

  bool matches(String value) => value.toLowerCase() == savedValue.toLowerCase();
  String get description => "be equal to '$savedValue' when ignoring case";
}

class _BeginsWith extends SimpleMatcher<String> {
  _BeginsWith(String value) : super(value);

  bool matches(String value) => value.startsWith(savedValue);
  String get description => "begin with '$savedValue'";
}

class _EndsWith extends SimpleMatcher<String> {
  _EndsWith(String value) : super(value);

  bool matches(String value) => value.endsWith(savedValue);
  String get description => "end with '$savedValue'";
}

class _Contains extends SimpleMatcher<String> {
  _Contains(String value) : super(value);

  bool matches(String value) => value.contains(savedValue, 0);
  String get description => "contain '$savedValue'";
}

class _MatchesRegExp implements Matcher<String> {
  RegExp _regexp;

  _MatchesRegExp(this._regexp);

  _MatchesRegExp.fromString(String regexp) : _regexp = new RegExp(regexp);

  bool matches(String value) => _regexp.hasMatch(value);
  String get description => "match '${_regexp.pattern}'";
}

class _StringForm implements Matcher {
  Matcher<String> _matcher;

  _StringForm(this._matcher);

  bool matches(value) => _matcher.matches("$value");
  String get description => "string ${_matcher.description}";
}

/// Every string that is empty (i.e., `it.isEmtpy()`) matches.
Matcher<String> empty() => new _Empty();

/// Every string that is equal to given [value] ignoring case
/// (i.e., `it.toLowerCase() == value.toLowerCase()`) matches.
Matcher<String> equalsIgnoreCase(String value) => new _EqualsIgnoreCase(value);

/// Every string that begins with given [value] (i.e., `it.startsWith(value)`)
/// matches.
Matcher<String> beginsWith(String value) => new _BeginsWith(value);

/// Every string that ends with given [value] (i.e., `it.endsWith(value)`)
/// matches.
Matcher<String> endsWith(String value) => new _EndsWith(value);

/// Every string that contains given [value] (i.e., `it.contains(value)`)
/// matches.
Matcher<String> contains(String value) => new _Contains(value);

/// Every string that matches given regular expression [pattern]
/// (i.e., `regexp.hasMatch(it)`) matches. Note that the [pattern]
/// can either be a [RegExp], in which case it is used directly,
/// or a [String], in which case it is passed to `new RegExp()`.
Matcher<String> matches(pattern) {
  if (pattern is String) {
    return new _MatchesRegExp.fromString(pattern);
  } else if (pattern is RegExp) {
    return new _MatchesRegExp(pattern);
  } else {
    throw new ArgumentError("'$pattern' must be String or RegExp");
  }
}

/// Matches only if the string form (as per `toString()`) matches given [matcher].
Matcher stringForm(Matcher<String> matcher) => new _StringForm(matcher);
